ALIF
----
An Adaptive Leaky Integrate Fire (ALIF) layer and variations thereof.

.. currentmodule:: sinabs.layers

.. autoclass:: ALIF
    :members:

ALIFRecurrent
-------------
.. autoclass:: ALIFRecurrent
    :members:
